==> kde-l10n-lt_4.8.2.orig.tar.xz: kde-l10n-lt-4.8.2/scripts/kdelibs/libplasma/plasmoids.js <==
// Use addCapitalDictCases where first letter is never lowercase (to avoid things like cPU or kDE).
addDictCases("Akys", "Akių", "Akims", "Akis", "Akimis", "Akyse");
addDictCases("Aparatinės įrangos informacija", "Aparatinės įrangos informacijos", "Aparatinės įrangos informacijai", "Aparatinės įrangos informaciją", "Aparatinės įrangos informacija", "Aparatinės įrangos informacijoje");
addDictCases("Aplanko rodymas", "Aplanko rodymo", "Aplanko rodymui", "Aplanko rodymą", "Aplanko rodymu", "Aplanko rodyme");
addDictCases("Analoginis laikrodis", "Analoginio laikrodžio", "Analoginiui laikrodžiui", "Analoginį laikrodį", "Analoginiu laikrodžiu", "Analoginiame laikrodyje");
addDictCases("Atminties būsena", "Atminties būsenos", "Atminties būsenai", "Atminties būseną", "Atminties būsena", "Atminties būsenoje");
addDictCases("Baterijos stebėtojas", "Baterijos stebėtojo", "Baterijos stebėtojui", "Baterijos stebėtoją", "Baterijos stebėtoju", "Baterijos stebėtojuje");
addDictCases("Bendruomenė", "Bendruomenės", "Bendruomenei", "Bendruomenę", "Bendruomene", "Bendruomenėje");
addCapitalDictCases("Chemija: ar žinojote", "Chemija: ar žinojote", "Chemija: ar žinojote", "Chemija: ar žinojote", "Chemija: ar žinojote", "Chemija: ar žinojote");
addCapitalDictCases("CPU apkrovos stebėtojas", "CPU apkrovos stebėtojo", "CPU apkrovos stebėtojui", "CPU apkrovos stebėtoją", "CPU apkrovos stebėtoju", "CPU apkrovos stebėtojuje");
addDictCases("Dabar grojama", "Dabar grojama", "Dabar grojama", "Dabar grojama", "Dabar grojama", "Dabar grojama");
addDictCases("Dabartinės programos valdymas", "Dabartinės programos valdymo", "Dabartinės programos valdymui", "Dabartinės programos valdymą", "Dabartinės programos valdymu", "Dabartinės programos valdyme");
addDictCases("Darbastalis", "Darbastalio", "Darbastaliui", "Darbastalį", "Darbastaliu", "Darbastalyje");
addDictCases("Dvejetainis laikrodis", "Dvejetainio laikrodžio", "Dvejetainiam laikrodžiui", "Dvejetainį laikrodį", "Dvejetainiu laikrodžiu", "Dvejetainiame laikrodyje");
addCapitalDictCases("Facebook", "Facebook", "Facebook", "Facebook", "Facebook", "Facebook");
addDictCases("Gauta žinutė", "Gautos žinutės", "Gautai žinutei", "Gautą žinutę", "Gauta žinute", "Gautoje žinutėje");
addDictCases("Gyvybė", "Gyvybės", "Gyvybei", "Gyvybę", "Gyvybe", "Gyvybėje");
addDictCases("Greitas paleidimas", "Greito paleidimo", "Greitam paleidimui", "Greitą paleidimą", "Greitu paleidimu", "Greitame paleidime");
addCapitalDictCases("KAlgebra", "KAlgebra", "KAlgebra", "KAlgebra", "KAlgebra", "KAlgebra");
addDictCases("Kalendorius", "Kalendoriaus", "Kalendoriui", "Kalendorių", "Kalendoriu", "Kalendoriuje");
addCapitalDictCases("KDE observatorija", "KDE observatorijos", "KDE observatorijai", "KDE observatoriją", "KDE observatorija", "KDE observatorijoje");
addDictCases("Kietųjų diskų būklė", "Kietųjų diskų būklės", "Kietųjų diskų būklei", "Kietųjų diskų būklę", "Kietųjų diskų būkle", "Kietųjų diskų būklėje");
addDictCases("Klaviatūra", "Klaviatūros", "Klaviatūrai", "Klaviatūrą", "Klaviatūra", "Klaviatūroje");
addDictCases("Klaviatūros išdėstymas", "Klaviatūros išdėstymo", "Klaviatūros išdėstymui", "Klaviatūros išdėstymą", "Klaviatūros išdėstymu", "Klaviatūros išdėstyme");
addDictCases("Konqueror profiliai", "Konqueror profilių", "Konqueror profiliams", "Konqueror profilius", "Konqueror profiliais", "Konqueror profiliuose");
addDictCases("Konsole profiliai", "Konsole profilių", "Konsole profiliams", "Konsole profilius", "Konsole profiliais", "Konsole profiliuose");
addCapitalDictCases("KTorrent", "KTorrent", "KTorrent", "KTorrent", "KTorrent", "KTorrent");
addDictCases("Laikmatis", "Laikmačio", "Laikmačiui", "Laikmatį", "Laikmačiu", "Laikmatyje");
addDictCases("Laikraščio išdėstymas", "Laikraščio išdėstymo", "Laikraščio išdėstymui", "Laikraščio išdėstymą", "Laikraščio išdėstymu", "Laikraščio išdėstyme");
addDictCases("Langų sąrašas", "Langų sąrašo", "Langų sąrašui", "Langų sąrašą", "Langų sąrašu", "Langų sąraše");
addDictCases("Naujienos", "Naujienų", "Naujienoms", "Naujienas", "Naujienomis", "Naujienose");
addDictCases("Netikslus laikrodis", "Netikslaus laikrodžio", "Netiksliam laikrodžiui", "Netikslų laikrodį", "Netiksliu laikrodžiu", "Netiksliame laikrodyje");
addDictCases("Orų prognozė", "Orų prognozės", "Orų prognozei", "Orų prognozę", "Orų prognoze", "Orų prognozėje");
addDictCases("Paieškos laukas", "Paieškos lauko", "Paieškos laukui", "Paieškos lauką", "Paieškos lauku", "Paieškos lauke");
addDictCases("Pasaulio laikrodis", "Pasaulio laikrodžio", "Pasaulio laikrodžiui", "Pasaulio laikrodį", "Pasaulio laikrodžiu", "Pasaulio laikrodyje");
addDictCases("Paveikslėlių rėmelis", "Paveikslėlių rėmelio", "Paveikslėlių rėmeliui", "Paveikslėlių rėmelį", "Paveikslėlių rėmeliu", "Paveikslėlių rėmelyje");
addDictCases("Penkiolika dalių", "Penkiolika dalių", "Penkiolika dalių", "Penkiolika dalių", "Penkiolika dalių", "Penkiolika dalių");
addDictCases("Peržiūriklis", "Peržiūriklio", "Peržiūrikliui", "Peržiūriklį", "Peržiūrikliu", "Peržiūriklyje");
addDictCases("Pranešimai", "Pranešimų", "Pranešimams", "Pranešimus", "Pranešimais", "Pranešimuose");
addDictCases("Pranešimai apie įrenginius", "Pranešimų apie įrenginius", "Pranešimams apie įrenginius", "Pranešimus apie įrenginius", "Pranešimais apie įrenginius", "Pranešimuose apie įrenginius");
addDictCases("Programų paleidiklio meniu", "Programų paleidiklio meniu", "Programų paleidiklio meniu", "Programų paleidiklio meniu", "Programų paleidiklio meniu", "Programų paleidiklio meniu");
addDictCases("Programų paleidiklis", "Programų paleidiklio", "Programų paleidikliui", "Programų paleidiklį", "Programų paleidikliu", "Programų paleidiklyje");
addDictCases("Puslapiuotojas", "Puslapiuotojo", "Puslapiuotojui", "Puslapiuotoją", "Puslapiuotoju", "Puslapiuotojuje");
addDictCases("Rasti ir paleisti", "Rasti ir paleisti", "Rasti ir paleisti", "Rasti ir paleisti", "Rasti ir paleisti", "Rasti ir paleisti");
addDictCases("Rodyti darbastalį", "Rodyti darbastalį", "Rodyti darbastalį", "Rodyti darbastalį", "Rodyti darbastalį", "Rodyti darbastalį");
addCapitalDictCases("RSSNOW", "RSSNOW", "RSSNOW", "RSSNOW", "RSSNOW", "RSSNOW");
addDictCases("Simbolių parinkiklis", "Simbolių parinkiklio", "Simbolių parinkikliui", "Simbolių parinkiklį", "Simbolių parinkikliu", "Simbolių parinkiklyje");
addDictCases("Sistemos apkrovos žiūriklis", "Sistemos apkrovos žiūriklio", "Sistemos apkrovos žiūrikliui", "Sistemos apkrovos žiūriklį", "Sistemos apkrovos žiūrikliu", "Sistemos apkrovos žiūriklyje");
addDictCases("Sistemos dėklas", "Sistemos dėklo", "Sistemos dėklui", "Sistemos dėklą", "Sistemos dėklu", "Sistemos dėkle");
addDictCases("Sistemos stebėtojas", "Sistemos stebėtojo", "Sistemos stebėtojui", "Sistemos stebėtoją", "Sistemos stebėtoju", "Sistemos stebėtojuje");
addDictCases("Skaičiuotuvas", "Skaičiuotuvo", "Skaičiuotuvui", "Skaičiuotuvą", "Skaičiuotuvu", "Skaičiuotuve");
addDictCases("Skaitmeninis laikrodis", "Skaitmeninio laikrodžio", "Skaitmeniniui laikrodžiui", "Skaitmeninį laikrodį", "Skaitmeniniu laikrodžiu", "Skaitmeniniame laikrodyje");
addDictCases("Skydelis", "Skydelio", "Skydeliui", "Skydelį", "Skydeliu", "Skydelyje");
addDictCases("Šiukšliadėžė", "Šiukšliadėžės", "Šiukšliadėžei", "Šiukšliadėžę", "Šiukšliadėže", "Šiukšliadėžėje");
addDictCases("Techninės įrangos temperatūra", "Techninės įrangos temperatūros", "Techninės įrangos temperatūrai", "Techninės įrangos temperatūrą", "Techninės įrangos temperatūra", "Techninės įrangos temperatūroje");
addDictCases("Tinklo stebėjimo priemonė", "Tinklo stebėjimo priemonės", "Tinklo stebėjimo priemonei", "Tinklo stebėjimo priemonę", "Tinklo stebėjimo priemone", "Tinklo stebėjimo priemonėje");
addDictCases("Užduočių tvarkyklė", "Užduočių tvarkyklės", "Užduočių tvarkyklei", "Užduočių tvarkyklę", "Užduočių tvarkykle", "Užduočių tvarkyklėje");
addDictCases("Užrakinti/atsijungti", "Užrakinti/atsijungti", "Užrakinti/atsijungti", "Užrakinti/atsijungti", "Užrakinti/atsijungti", "Užrakinti/atsijungti");
addDictCases("Užrašai", "Užrašų", "Užrašams", "Užrašus", "Užrašais", "Užrašuose");
addDictCases("Veiklų juosta", "Veiklų juostos", "Veiklų juostai", "Veiklų juostą", "Veiklų juosta", "Veiklų juostoje");
addDictCases("Vienetų konvertuoklis", "Vienetų konvertuoklio", "Vienetų konvertuokliui", "Vienetų konvertuoklį", "Vienetų konvertuokliu", "Vienetų konvertuoklyje");
addDictCases("Ženkliukas", "Ženkliuko", "Ženkliukui", "Ženkliuką", "Ženkliuku", "Ženkliuke");
addDictCases("Žiniatinklio naršyklė", "Žiniatinklio naršyklės", "Žiniatinklio naršyklei", "Žiniatinklio naršyklę", "Žiniatinklio naršykle", "Žiniatinklio naršyklėje");
addDictCases("Žymelės", "Žymelių", "Žymelėms", "Žymeles", "Žymelėmis", "Žymelėse");
addDictCases("Žodynas", "Žodyno", "Žodynui", "Žodyną", "Žodynu", "Žodyne");

==> kde-l10n-lt-4.8.5.tar.xz: kde-l10n-lt-4.8.5/scripts/kdelibs/libplasma/plasmoids.js <==
// Use addCapitalDictCases where first letter is never lowercase (to avoid things like cPU or kDE).
addDictCases("Akys", "Akių", "Akims", "Akis", "Akimis", "Akyse");
addDictCases("Aknotes pastabos plazmoidas", "Aknotes pastabos plazmoido", "Aknotes pastabos plazmoidui", "Aknotes pastabos plazmoidą", "Aknotes pastabos plazmoidu", "Aknotes pastabos plazmoide");
addDictCases("Aknotes sąrašo plazmoidas", "Aknotes sąrašo plazmoido", "Aknotes sąrašo plazmoidui", "Aknotes sąrašo plazmoidą", "Aknotes sąrašo plazmoidu", "Aknotes sąrašo plazmoide");
addDictCases("Analoginis laikrodis", "Analoginio laikrodžio", "Analoginiui laikrodžiui", "Analoginį laikrodį", "Analoginiu laikrodžiu", "Analoginiame laikrodyje");
addDictCases("Aparatinės įrangos informacija", "Aparatinės įrangos informacijos", "Aparatinės įrangos informacijai", "Aparatinės įrangos informaciją", "Aparatinės įrangos informacija", "Aparatinės įrangos informacijoje");
addDictCases("Aplanko rodymas", "Aplanko rodymo", "Aplanko rodymui", "Aplanko rodymą", "Aplanko rodymu", "Aplanko rodyme");
addDictCases("Atminties būsena", "Atminties būsenos", "Atminties būsenai", "Atminties būseną", "Atminties būsena", "Atminties būsenoje");
addDictCases("Baterijos stebėtojas", "Baterijos stebėtojo", "Baterijos stebėtojui", "Baterijos stebėtoją", "Baterijos stebėtoju", "Baterijos stebėtojuje");
addDictCases("Bendruomenė", "Bendruomenės", "Bendruomenei", "Bendruomenę", "Bendruomene", "Bendruomenėje");
addCapitalDictCases("Chemija: ar žinojote", "Chemija: ar žinojote", "Chemija: ar žinojote", "Chemija: ar žinojote", "Chemija: ar žinojote", "Chemija: ar žinojote");
addCapitalDictCases("CPU apkrovos stebėtojas", "CPU apkrovos stebėtojo", "CPU apkrovos stebėtojui", "CPU apkrovos stebėtoją", "CPU apkrovos stebėtoju", "CPU apkrovos stebėtojuje");
addDictCases("Dabar grojama", "Dabar grojama", "Dabar grojama", "Dabar grojama", "Dabar grojama", "Dabar grojama");
addDictCases("Dabartinės programos valdymas", "Dabartinės programos valdymo", "Dabartinės programos valdymui", "Dabartinės programos valdymą", "Dabartinės programos valdymu", "Dabartinės programos valdyme");
addDictCases("Darbastalis", "Darbastalio", "Darbastaliui", "Darbastalį", "Darbastaliu", "Darbastalyje");
addDictCases("Dvejetainis laikrodis", "Dvejetainio laikrodžio", "Dvejetainiam laikrodžiui", "Dvejetainį laikrodį", "Dvejetainiu laikrodžiu", "Dvejetainiame laikrodyje");
addCapitalDictCases("Facebook", "Facebook", "Facebook", "Facebook", "Facebook", "Facebook");
addDictCases("Failų stebėtojas", "Failų stebėtojo", "Failų stebėtojui", "Failų stebėtoją", "Failų stebėtoju", "Failų stebėtojuje");
addDictCases("Gauta žinutė", "Gautos žinutės", "Gautai žinutei", "Gautą žinutę", "Gauta žinute", "Gautoje žinutėje");
addDictCases("Gyvybė", "Gyvybės", "Gyvybei", "Gyvybę", "Gyvybe", "Gyvybėje");
addDictCases("Greitas paleidimas", "Greito paleidimo", "Greitam paleidimui", "Greitą paleidimą", "Greitu paleidimu", "Greitame paleidime");
addDictCases("Įvesties metodo skydelis", "Įvesties metodo skydelio", "Įvesties metodo skydeliui", "Įvesties metodo skydelį", "Įvesties metodo skydeliu", "Įvesties metodo skydelyje");
addDictCases("Kalendorius", "Kalendoriaus", "Kalendoriui", "Kalendorių", "Kalendoriu", "Kalendoriuje");
addCapitalDictCases("KAlgebra", "KAlgebra", "KAlgebra", "KAlgebra", "KAlgebra", "KAlgebra");
addCapitalDictCases("Kate sesijų programėlė", "Kate sesijų programėlės", "Kate sesijų programėlei", "Kate sesijų programėlę", "Kate sesijų programėle", "Kate sesijų programėlėje");
addCapitalDictCases("KDE observatorija", "KDE observatorijos", "KDE observatorijai", "KDE observatoriją", "KDE observatorija", "KDE observatorijoje");
addCapitalDictCases("KGet skritulinės diagramos programėlė", "KGet skritulinės diagramos programėlės", "KGet skritulinės diagramos programėlei", "KGet skritulinės diagramos programėlę", "KGet skritulinės diagramos programėle", "KGet skritulinės diagramos programėlėje");
addCapitalDictCases("KGet stulpelinės diagramos programėlė", "KGet stulpelinės diagramos programėlės", "KGet stulpelinės diagramos programėlei", "KGet stulpelinės diagramos programėlę", "KGet stulpelinės diagramos programėle", "KGet stulpelinės diagramos programėlėje");
addDictCases("Kietųjų diskų būklė", "Kietųjų diskų būklės", "Kietųjų diskų būklei", "Kietųjų diskų būklę", "Kietųjų diskų būkle", "Kietųjų diskų būklėje");
addDictCases("Klaviatūra", "Klaviatūros", "Klaviatūrai", "Klaviatūrą", "Klaviatūra", "Klaviatūroje");
addDictCases("Klaviatūros išdėstymas", "Klaviatūros išdėstymo", "Klaviatūros išdėstymui", "Klaviatūros išdėstymą", "Klaviatūros išdėstymu", "Klaviatūros išdėstyme");
addDictCases("Konqueror profiliai", "Konqueror profilių", "Konqueror profiliams", "Konqueror profilius", "Konqueror profiliais", "Konqueror profiliuose");
addDictCases("Konsole profiliai", "Konsole profilių", "Konsole profiliams", "Konsole profilius", "Konsole profiliais", "Konsole profiliuose");
addCapitalDictCases("KTorrent", "KTorrent", "KTorrent", "KTorrent", "KTorrent", "KTorrent");
addDictCases("Laikmatis", "Laikmačio", "Laikmačiui", "Laikmatį", "Laikmačiu", "Laikmatyje");
addDictCases("Laikraščio išdėstymas", "Laikraščio išdėstymo", "Laikraščio išdėstymui", "Laikraščio išdėstymą", "Laikraščio išdėstymu", "Laikraščio išdėstyme");
addCapitalDictCases("Lancelot paleidiklis", "Lancelot paleidiklio", "Lancelot paleidikliui", "Lancelot paleidiklį", "Lancelot paleidikliu", "Lancelot paleidiklyje");
addDictCases("Langų sąrašas", "Langų sąrašo", "Langų sąrašui", "Langų sąrašą", "Langų sąrašu", "Langų sąraše");
addCapitalDictCases("LCD orų stotelė", "LCD orų stotelės", "LCD orų stotelei", "LCD orų stotelę", "LCD orų stotele", "LCD orų stotelėje");
addDictCases("Lenta", "Lentos", "Lentai", "Lentą", "Lenta", "Lentoje");
addDictCases("Lentyna", "Lentynos", "Lentynai", "Lentyną", "Lentyna", "Lentynoje");
addCapitalDictCases("Luna", "Luna", "Luna", "Luna", "Luna", "Luna");
addCapitalDictCases("Magnifique", "Magnifique", "Magnifique", "Magnifique", "Magnifique", "Magnifique");
addDictCases("Media leistuvė", "Media leistuvės", "Media leistuvei", "Media leistuvę", "Media leistuve", "Media leistuvėje");
addDictCases("Mikrotinklaraštis", "Mikrotinklaraščio", "Mikrotinklaraščiui", "Mikrotinklaraštį", "Mikrotinklaraščiu", "Mikrotinklaraštyje");
addDictCases("Naujienos", "Naujienų", "Naujienoms", "Naujienas", "Naujienomis", "Naujienose");
addDictCases("Netikslus laikrodis", "Netikslaus laikrodžio", "Netiksliam laikrodžiui", "Netikslų laikrodį", "Netiksliu laikrodžiu", "Netiksliame laikrodyje");
addDictCases("Orų prognozė", "Orų prognozės", "Orų prognozei", "Orų prognozę", "Orų prognoze", "Orų prognozėje");
addCapitalDictCases("Padėti", "Padėti", "Padėti", "Padėti", "Padėti", "Padėti");
addDictCases("Paieškos laukas", "Paieškos lauko", "Paieškos laukui", "Paieškos lauką", "Paieškos lauku", "Paieškos lauke");
addCapitalDictCases("Palikti pranešimą", "Palikti pranešimą", "Palikti pranešimą", "Palikti pranešimą", "Palikti pranešimą", "Palikti pranešimą");
addCapitalDictCases("Parley", "Parley", "Parley", "Parley", "Parley", "Parley");
addDictCases("Pasaulio laikrodis", "Pasaulio laikrodžio", "Pasaulio laikrodžiui", "Pasaulio laikrodį", "Pasaulio laikrodžiu", "Pasaulio laikrodyje");
addCapitalDictCases("Pastebin", "Pastebin", "Pastebin", "Pastebin", "Pastebin", "Pastebin");
addDictCases("Paveikslėlių rėmelis", "Paveikslėlių rėmelio", "Paveikslėlių rėmeliui", "Paveikslėlių rėmelį", "Paveikslėlių rėmeliu", "Paveikslėlių rėmelyje");
addDictCases("Penkiolika dalių", "Penkiolika dalių", "Penkiolika dalių", "Penkiolika dalių", "Penkiolika dalių", "Penkiolika dalių");
addDictCases("Peržiūriklis", "Peržiūriklio", "Peržiūrikliui", "Peržiūriklį", "Peržiūrikliu", "Peržiūriklyje");
addDictCases("Pranešimai apie įrenginius", "Pranešimų apie įrenginius", "Pranešimams apie įrenginius", "Pranešimus apie įrenginius", "Pranešimais apie įrenginius", "Pranešimuose apie įrenginius");
addDictCases("Pranešimai", "Pranešimų", "Pranešimams", "Pranešimus", "Pranešimais", "Pranešimuose");
addCapitalDictCases("Prisimink pieną", "Prisimink pieną", "Prisimink pieną", "Prisimink pieną", "Prisimink pieną", "Prisimink pieną");
addDictCases("Programų paleidiklio meniu", "Programų paleidiklio meniu", "Programų paleidiklio meniu", "Programų paleidiklio meniu", "Programų paleidiklio meniu", "Programų paleidiklio meniu");
addDictCases("Programų paleidiklis", "Programų paleidiklio", "Programų paleidikliui", "Programų paleidiklį", "Programų paleidikliu", "Programų paleidiklyje");
addDictCases("Puslapiuotojas", "Puslapiuotojo", "Puslapiuotojui", "Puslapiuotoją", "Puslapiuotoju", "Puslapiuotojuje");
addCapitalDictCases("Qalculate!", "Qalculate!", "Qalculate!", "Qalculate!", "Qalculate!", "Qalculate!");
addCapitalDictCases("Rasti ir paleisti", "Rasti ir paleisti", "Rasti ir paleisti", "Rasti ir paleisti", "Rasti ir paleisti", "Rasti ir paleisti");
addDictCases("Rašybos tikrinimas", "Rašybos tikrinimo", "Rašybos tikrinimui", "Rašybos tikrinimą", "Rašybos tikrinimu", "Rašybos tikrinime");
addDictCases("Rodyti darbastalį", "Rodyti darbastalį", "Rodyti darbastalį", "Rodyti darbastalį", "Rodyti darbastalį", "Rodyti darbastalį");
addCapitalDictCases("RSSNOW", "RSSNOW", "RSSNOW", "RSSNOW", "RSSNOW", "RSSNOW");
addDictCases("Simbolių parinkiklis", "Simbolių parinkiklio", "Simbolių parinkikliui", "Simbolių parinkiklį", "Simbolių parinkikliu", "Simbolių parinkiklyje");
addDictCases("Sistemos apkrovos žiūriklis", "Sistemos apkrovos žiūriklio", "Sistemos apkrovos žiūrikliui", "Sistemos apkrovos žiūriklį", "Sistemos apkrovos žiūrikliu", "Sistemos apkrovos žiūriklyje");
addDictCases("Sistemos dėklas", "Sistemos dėklo", "Sistemos dėklui", "Sistemos dėklą", "Sistemos dėklu", "Sistemos dėkle");
addDictCases("Sistemos stebėtojas", "Sistemos stebėtojo", "Sistemos stebėtojui", "Sistemos stebėtoją", "Sistemos stebėtoju", "Sistemos stebėtojuje");
addDictCases("Skaičiuotuvas", "Skaičiuotuvo", "Skaičiuotuvui", "Skaičiuotuvą", "Skaičiuotuvu", "Skaičiuotuve");
addDictCases("Skaitmeninis laikrodis", "Skaitmeninio laikrodžio", "Skaitmeniniui laikrodžiui", "Skaitmeninį laikrodį", "Skaitmeniniu laikrodžiu", "Skaitmeniniame laikrodyje");
addDictCases("Skydelis", "Skydelio", "Skydeliui", "Skydelį", "Skydeliu", "Skydelyje");
addDictCases("Spalvų parinkiklis", "Spalvų parinkiklio", "Spalvų parinkikliui", "Spalvų parinkiklį", "Spalvų parinkikliu", "Spalvų parinkiklyje");
addDictCases("Šiukšliadėžė", "Šiukšliadėžės", "Šiukšliadėžei", "Šiukšliadėžę", "Šiukšliadėže", "Šiukšliadėžėje");
addDictCases("Šokinėjantis kamuolys", "Šokinėjančio kamuolio", "Šokinėjančiam kamuoliui", "Šokinėjantį kamuolį", "Šokinėjančiu kamuoliu", "Šokinėjančiame kamuolyje");
addDictCases("Techninės įrangos temperatūra", "Techninės įrangos temperatūros", "Techninės įrangos temperatūrai", "Techninės įrangos temperatūrą", "Techninės įrangos temperatūra", "Techninės įrangos temperatūroje");
addDictCases("Tik ženkliukų užduočių tvarkytuvė", "Tik ženkliukų užduočių tvarkytuvės", "Tik ženkliukų užduočių tvarkytuvei", "Tik ženkliukų užduočių tvarkytuvę", "Tik ženkliukų užduočių tvarkytuve", "Tik ženkliukų užduočių tvarkytuvėje");
addDictCases("Tinklo stebėjimo priemonė", "Tinklo stebėjimo priemonės", "Tinklo stebėjimo priemonei", "Tinklo stebėjimo priemonę", "Tinklo stebėjimo priemone", "Tinklo stebėjimo priemonėje");
addDictCases("Tinklo valdymas", "Tinklo valdymo", "Tinklo valdymui", "Tinklo valdymą", "Tinklo valdymu", "Tinklo valdyme");
addDictCases("Užduočių tvarkyklė", "Užduočių tvarkyklės", "Užduočių tvarkyklei", "Užduočių tvarkyklę", "Užduočių tvarkykle", "Užduočių tvarkyklėje");
addDictCases("Užrakinti/atsijungti", "Užrakinti/atsijungti", "Užrakinti/atsijungti", "Užrakinti/atsijungti", "Užrakinti/atsijungti", "Užrakinti/atsijungti");
addDictCases("Užrašai", "Užrašų", "Užrašams", "Užrašus", "Užrašais", "Užrašuose");
addDictCases("Veiklos", "Veiklų", "Veikloms", "Veiklas", "Veiklomis", "Veiklose");
addDictCases("Veiklų juosta", "Veiklų juostos", "Veiklų juostai", "Veiklų juostą", "Veiklų juosta", "Veiklų juostoje");
addDictCases("Vienetų konvertuoklis", "Vienetų konvertuoklio", "Vienetų konvertuokliui", "Vienetų konvertuoklį", "Vienetų konvertuokliu", "Vienetų konvertuoklyje");
addDictCases("Ženkliukas", "Ženkliuko", "Ženkliukui", "Ženkliuką", "Ženkliuku", "Ženkliuke");
addDictCases("Žiniatinklio naršyklė", "Žiniatinklio naršyklės", "Žiniatinklio naršyklei", "Žiniatinklio naršyklę", "Žiniatinklio naršykle", "Žiniatinklio naršyklėje");
addDictCases("Žymelės", "Žymelių", "Žymelėms", "Žymeles", "Žymelėmis", "Žymelėse");
addDictCases("Žodynas", "Žodyno", "Žodynui", "Žodyną", "Žodynu", "Žodyne");
